pub struct Module {
pub max_batch_size: Option<u32>,
// some fields omitted
}
pub fn is_content_onto(
&self,
cmd: IndvOp,
new_state: &mut Individual,
prev_state: &mut Individual
) -> boolpub fn listen_queue_raw<T>(
&mut self,
queue_consumer: &mut Consumer,
module_context: &mut T,
before_batch: &mut fn(_: &mut Backend, _: &mut T, batch_size: u32) -> Option<u32>,
prepare: &mut fn(_: &mut Backend, _: &mut T, _: &RawObj, _: &Consumer) -> Result<bool, PrepareError>,
after_batch: &mut fn(_: &mut Backend, _: &mut T, prepared_batch_size: u32) -> Result<bool, PrepareError>,
heartbeat: &mut fn(_: &mut Backend, _: &mut T) -> Result<(), PrepareError>,
backend: &mut Backend
)pub fn listen_queue<T>(
&mut self,
queue_consumer: &mut Consumer,
module_context: &mut T,
before_batch: &mut fn(_: &mut Backend, _: &mut T, batch_size: u32) -> Option<u32>,
prepare: &mut fn(_: &mut Backend, _: &mut T, _: &mut Individual, _: &Consumer) -> Result<bool, PrepareError>,
after_batch: &mut fn(_: &mut Backend, _: &mut T, prepared_batch_size: u32) -> Result<bool, PrepareError>,
heartbeat: &mut fn(_: &mut Backend, _: &mut T) -> Result<(), PrepareError>,
backend: &mut Backend
)
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
pub unsafe fn init(init: <T as Pointable>::Init) -> usize
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,